@@ -2,6 +2,7 @@ from .APIClients import APIClientBase
 from .EthosLoginSession import EthosLoginSessionBasedOnAPIKey
 from .ResourceWrappers import getResourceWrapper
 from .ResourceIterator import ResourceIterator
+from .ListBasedResourceIterator import ListBasedResourceIterator
 from .EthosChangeNotificationPollerThread import EthosChangeNotificationPollerThreadQueueMode, EthosChangeNotificationPollerThreadFunctionMode
 import json
 
@@ -46,8 +47,11 @@ class EllucianEthosAPIClient(APIClientBase):
       return None
     return getResourceWrapper(clientAPIInstance=self, dict=json.loads(resultContent), version=versionReturned, resourseName=resourceName)
 
-  def getResourceIterator(self, loginSession, resourceName, version=None, pageSize=25):
-    return ResourceIterator(self, loginSession, resourceName, version, pageSize)
+  def getResourceIterator(self, loginSession, resourceName, version=None, pageSize=25, params=None):
+    return ResourceIterator(self, loginSession, resourceName, version, pageSize, params=params)
+
+  def getListBasedResourceIterator(self, loginSession, resourceName, resourceIDList, version=None):
+    return ListBasedResourceIterator(self, loginSession, resourceName, version, resourceIDList=resourceIDList)
 
   def getVersionIntFromHeader(self, meaidTypeHeaderValue):
     #example: application/vnd.hedtech.integration.v6+json
